@@ -1,10 +1,8 @@
 import os
 import re
-import shlex
-import subprocess
 from itertools import count
 from pathlib import Path
-from typing import List, Tuple
+from typing import List
 
 DEFAULT_TIMEOUT = 120
 MIGRATION_REGEX = (
@@ -13,49 +11,17 @@ MIGRATION_REGEX = (
 
 
 def _clean_message(output: str) -> str:
+    """Strips the succeeding new line and carriage return characters."""
     return output.rstrip("\n\r")
 
 
 def _decode_message(output: bytes, encoding: str) -> str:
+    """Converts bytes to string, stripping white spaces."""
     return output.decode(encoding).strip()
 
 
-def run_command(
-    command: str, encoding: str = "utf-8", timeout: int = DEFAULT_TIMEOUT
-) -> Tuple[bool, str, str]:
-    command = shlex.split(command)
-    process = subprocess.Popen(
-        command,
-        encoding=encoding,
-        stdout=subprocess.PIPE,
-        stderr=subprocess.STDOUT,
-    )
-
-    try:
-        output, error = process.communicate(timeout=timeout)
-    except subprocess.TimeoutExpired:
-        process.kill()
-        output, error = process.communicate()
-
-    output = output or ""
-    error = error or ""
-
-    if isinstance(output, bytes):
-        output = _decode_message(output, encoding)
-
-    if isinstance(error, bytes):
-        error = _decode_message(error, encoding)
-
-    output = _clean_message(output)
-    error = _clean_message(error)
-
-    exit_code = process.poll()
-    has_no_errors = exit_code == 0
-
-    return has_no_errors, output, error
-
-
 def _update_migration(conflict_path: Path, app_label: str, seen: List[str]) -> None:
+    """Modify the migration file."""
     replacement = "('{app_label}', '{prev_migration}'),".format(
         app_label=app_label,
         prev_migration=seen[-1],
@@ -85,6 +51,7 @@ def fix_numbered_migration(
     start_name: str,
     changed_files: List[str],
 ):
+    """Resolve migration conflicts for numbered migrations."""
     seen = [start_name]
     counter = count(seed + 1)  # 0537 -> 538
     sorted_changed_files = sorted(changed_files, key=lambda p: p.split("_")[0])
@@ -114,13 +81,14 @@ def fix_numbered_migration(
             seen.append(new_conflict_name.strip(".py"))
 
 
-def fix_migration(
+def fix_named_migration(
     *,
     app_label: str,
     migration_path: Path,
     start_name: str,
     changed_files: List[str],
 ):
+    """Resolve migration conflicts for named migrations."""
     seen = [start_name]
 
     for path in changed_files:
@@ -131,3 +99,21 @@ def fix_migration(
             _update_migration(conflict_path, app_label, seen)
 
             seen.append(basename.strip(".py"))
+
+
+def no_translations(handle_func):
+    """Decorator that forces a command to run with translations deactivated."""
+
+    def wrapped(*args, **kwargs):
+        from django.utils import translation
+
+        saved_locale = translation.get_language()
+        translation.deactivate_all()
+        try:
+            res = handle_func(*args, **kwargs)
+        finally:
+            if saved_locale is not None:
+                translation.activate(saved_locale)
+        return res
+
+    return wrapped
